datablock ItemData(PlaceSentryRocketItem)
{
	category = "Item";  // Mission editor category
	
	shapeFile = "./sentryTookitRocket.dts";
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Toolkit - Rocket";
	iconName = "./icon_sentry_rocket";
	doColorShift = false;
	colorShiftColor = "0.200 0.200 0.200 1.000";
	
	image = PlaceSentryRocketImage;
	canDrop = true;
};

datablock ShapeBaseImageData(PlaceSentryRocketImage : PlaceSentryImage)
{
   // Basic Item properties
   shapeFile = "./sentryTookitRocket.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;

   //doColorShift = true;
	 //colorShiftColor = PlaceSentryRocketItem.colorShiftColor;
	 
   correctMuzzleVector = false;
   className = "ToolImage";
	 
   item = PlaceSentryRocketItem;

   //melee particles shoot from eye node for consistancy
   melee = true;
   //raise your arm up or not
   armReady = false;

	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.5;
	stateTransitionOnTimeout[0]       = "Ready";
	stateScript[0]                  = "onActivate";
	stateSequence[0]                  = "Activate";

	stateName[1]                     = "Ready";
	stateScript[1]                  = "onUse";
	stateTransitionOnTriggerDown[1]  = "Fire";
	stateAllowImageChange[1]         = true;

	stateName[2]                    = "Fire";
	stateTransitionOnTriggerUp[2]	= "Ready";
	stateScript[2]                  = "onFire";

	minShotTime = 1000;
};

function PlaceSentryRocketImage::onMount(%this, %obj, %slot)
{
	if((%obj.lastFireTime+%this.minShotTime) > getSimTime())
		{
		centerprint(%obj.client,"Can't deploy another sentry yet!<br><br>Give it a minute or so to respawn..." ,5);
		serverCmdUnUseTool(%obj.client);
		%obj.playThread(2, undo);
		return;
		}

	%obj.playthread(1, armReadyBoth);
}

function PlaceSentryRocketImage::onUnMount(%this,%obj,%slot)
{
		%obj.playThread(0, root);
}

function PlaceSentryRocketImage::onActivate(%this, %obj, %slot)
{
	%obj.playthread(1, armReadyBoth);
	%obj.lastcrateslot = %obj.currTool;
}

function PlaceSentryRocketImage::onFire(%this, %obj, %slot)
{
	createRocketSentryAtPlayer(%obj.client.player);

	%currSlot = %obj.lastcrateslot;
	%obj.tool[%currSlot] = 0;
	%obj.weaponCount--;
	messageClient(%obj.client,'MsgItemPickup','',%currSlot,0);
	serverCmdUnUseTool(%obj.client);
	%obj.playThread(1, plant);
	%obj.playThread(2, activate2);

	%obj.lastFireTime = getSimTime();
  %fvec = %obj.getForwardVector();
  %fX = getWord(%fvec,0);
  %fY = getWord(%fvec,1);
  
  %evec = %obj.getEyeVector();
  %eX = getWord(%evec,0);
  %eY = getWord(%evec,1);
  %eZ = getWord(%evec,2);
  
  %eXY = mSqrt(%eX*%eX+%eY*%eY);
  
  %aimVec = %fX*%eXY SPC %fY*%eXY SPC %eZ;

	%obj.setVelocity(VectorAdd(%obj.getVelocity(),VectorScale(%aimVec,"-8")));

  serverPlay3D(sentryBuildSound, %obj.getPosition());
}

function createRocketSentryAtPlayer(%player)
{
	if($sentryOnePerPlayer)
	{
		for(%i = 0; %i < sentryGroup.getCount(); %i++)
		{
			if(isObject(sentryGroup.getObject(%i).sentryOwner) && sentryGroup.getObject(%i).sentryOwner == %player.client)
			{
				sentryGroup.getObject(%i).kill();
			}
		}
	}
	%pos = vectorAdd(vectorScale(%player.getForwardVector(), 3) @ " 0 0 0 0", %player.getTransform());
	%bottom = new AIPlayer()
	{
		datablock = "PlayerSentryBottom";
		position = %pos;
		sentryOwner = %player.client;
		tdmTeam = %player.client.tdmTeam;
		slyrteam = %player.client.slyrteam;
		sentryKit = "Default";
		sentryXP = 0;
	};
	%top = new AIPlayer()
	{
		datablock = "PlayerSentryTop";
		sentryBottom = %bottom;
		sentryOwner = %player.client;
		tdmTeam = %player.client.tdmTeam;
		slyrteam = %player.client.slyrteam;
	};

///////////////////////////////////////////////////////////////////////////////////////////////////////////////

%p = new Projectile()
  {
     dataBlock = toolboxExplosionProjectile;
     initialPosition = %pos;
     initialVelocity = "0 0 1";
     client = %obj.client;
     sourceClient = %obj.client;
  };

///////////////////////////////////////////////////////////////////////////////////////////////////////////////
	%top.client = %top;
	%top.player = %top;
	%top.minigame = %player.client.minigame;
	%top.sentryLevel = 1;
	%top.sentryKit = "Rocket";
	
	%bottom.client = %bottom;
	%bottom.player = %bottom;
	%bottom.minigame = %player.client.minigame;
	
	%top.hideNode("invisible");

	%bottom.mountObject(%top, 0);
	%top.setControlObject(%top); //must do this or it spins in circles
	
	%bottom.sentryTop = %top;
	sentryGroup.add(%top);
	
	%top.mountImage($sentryImage_Rocket_1, 0);
	
	if(!isEventPending($sentryLogicLoopSched))
		sentryLogicLoop();
}